@@ -206,7 +206,7 @@ void check_admin_list(void) {
 /* Show help info.
  */
 static void show_help(FILE *fp) {
-	fprintf(fp,	"  ban <ip>[,<time>]: ban an IP (for <time> seconds)\n"
+	fprintf(fp,	"  ban <ip>[ <time>]: ban an IP (for <time> seconds)\n"
 				"  clear screen     : clear the screen\n"
 #ifdef HAVE_CACHE
 				"        cache      : remove all unlocked files from the cache\n"
@@ -260,7 +260,7 @@ static int run_command(char *line, FILE *fp, t_config *config) {
 		if (param == NULL) {
 			fprintf(fp, "  ban what?\n");
 		} else {
-			if (split_string(param, &param, &param2, ',') == 0) {
+			if (split_string(param, &param, &param2, ' ') == 0) {
 				time = str2int(param2);
 			} else {
 				time = TIMER_OFF;
