@@ -166,7 +166,7 @@ void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
 #endif
 		add_to_environment_chroot(session, fcgi_buffer, "DOCUMENT_ROOT", session->host->website_root);
 
-	if (inet_ntop(session->ip_address.family, &(session->ip_address.value), ip, MAX_IP_STR_LEN) != NULL) {
+	if (ip_to_str(ip, &(session->ip_address), MAX_IP_STR_LEN) != -1) {
 		add_to_environment(fcgi_buffer, "REMOTE_ADDR", ip);
 	}
 
@@ -190,6 +190,9 @@ void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
 	if (session->binding->binding_id != NULL) {
 		add_to_environment(fcgi_buffer, "SERVER_BINDING", session->binding->binding_id);
 	}
+	if (ip_to_str(ip, &(session->binding->interface), MAX_IP_STR_LEN) != -1) {
+		add_to_environment(fcgi_buffer, "SERVER_ADDR", ip);
+	}
 	add_to_environment(fcgi_buffer, "REDIRECT_STATUS", "200");
 
 	if (session->remote_user != NULL) {
@@ -230,9 +233,14 @@ void set_environment(t_session *session, t_fcgi_buffer *fcgi_buffer) {
 #ifdef HAVE_SSL
 	if (session->binding->use_ssl) {
 		add_to_environment(fcgi_buffer, "HTTP_SCHEME", "https");
-	} else
+		add_to_environment(fcgi_buffer, "HTTPS", "on");
+	} else {
 #endif
 		add_to_environment(fcgi_buffer, "HTTP_SCHEME", "http");
+#ifdef HAVE_SSL
+		add_to_environment(fcgi_buffer, "HTTPS", "off");
+	}
+#endif
 
 	if (session->path_info != NULL) {
 		add_to_environment(fcgi_buffer, "PATH_INFO", session->path_info);
