@@ -86,7 +86,7 @@
 #define RANDOM_BUFFER_SIZE     512
 
 #define NO_REQUEST_LIMIT_TIME  300
-#define NO_REQUEST_LIMIT_SIZE    8 * MEGABYTE
+#define NO_REQUEST_LIMIT_SIZE   16 * MEGABYTE
 
 typedef struct {
 	char *config_dir;
@@ -95,7 +95,7 @@ typedef struct {
 } t_settings;
 
 volatile int received_signal = rs_NONE;
-bool               must_quit = false;
+bool must_quit = false;
 int open_connections = 0;
 
 char *hs_conlen      = "Content-Length: ";
@@ -358,12 +358,10 @@ int fetch_request(t_session *session) {
 	time_t deadline;
 	fd_set read_fds;
 	struct timeval select_timeout;
-	bool keep_reading = true, store_on_disk = false, request_limit;
+	bool keep_reading = true, store_on_disk = false;
 	int upload_handle = -1;
 
-	request_limit = ip_allowed(&(session->ip_address), session->config->request_limit_mask) != deny;
-
-	if (request_limit == false) {
+	if (session->request_limit == false) {
 		deadline = session->time + NO_REQUEST_LIMIT_TIME;
 		max_request_size = NO_REQUEST_LIMIT_SIZE;
 	} else if (session->kept_alive == 0) {
@@ -613,6 +611,7 @@ int parse_request(t_session *session, int total_bytes) {
 		return 400;
 	}
 	*(str_end++) = '\0';
+	session->uri_len = strlen(session->uri);
 	if (strncmp(session->uri, "http://", 7) == 0) {
 		return 400;
 	} else if ((session->request_uri = strdup(session->uri)) == NULL) {
@@ -783,18 +782,16 @@ t_access allow_client(t_session *session) {
 int get_path_info(t_session *session) {
 	t_fsbool is_dir;
 	char *slash;
-	int len;
 
 	if (session->alias_used) {
 		return 200;
 	}
 
-	len = session->host->website_root_len;
-	if (len >= strlen(session->file_on_disk)) {
+	if (session->host->website_root_len >= strlen(session->file_on_disk)) {
 		return 500;
 	}
 
-	slash = session->file_on_disk + len + 1;
+	slash = session->file_on_disk + session->host->website_root_len + 1;
 	while (*slash != '\0') {
 		if (*slash == '/') {
 			*slash = '\0';
@@ -862,7 +859,9 @@ int serve_client(t_session *session) {
 
 			if (*client_ip != '\0') {
 				if (parse_ip(client_ip, &ip) != -1) {
-					copy_ip(&(session->ip_address), &ip);
+					if (reposition_client(session, &ip) != -1) {
+						copy_ip(&(session->ip_address), &ip);
+					}
 				}
 			}
 		}
@@ -884,6 +883,8 @@ int serve_client(t_session *session) {
 	}
 
 	if (session->hostname != NULL) {
+		remove_port_from_hostname(session->hostname, session->binding);
+
 		if ((host_record = get_hostrecord(session->config->first_host, session->hostname, session->binding)) != NULL) {
 			session->host = host_record;
 #ifdef HAVE_COMMAND
@@ -893,6 +894,18 @@ int serve_client(t_session *session) {
 	}
 	session->host->access_time = session->time;
 
+#ifdef HAVE_SSL
+	if (session->host->require_ssl && (session->binding->use_ssl == false)) {
+		if ((qmark = strchr(session->uri, '?')) != NULL) {
+			*qmark = '\0';
+			session->vars = qmark + 1;
+			session->uri_len = strlen(session->uri);
+		}
+		session->cause_of_301 = require_ssl;
+		return 301;
+	}
+#endif
+
 	if (session->host->secure_url) {
 		if (strstr(session->request_uri, "%00") != NULL) {
 			return 403;
@@ -1041,13 +1054,6 @@ int serve_client(t_session *session) {
 		}
 	}
 
-#ifdef HAVE_SSL
-	if (session->host->require_ssl && (session->binding->use_ssl == false)) {
-		session->cause_of_301 = require_ssl;
-		return 301;
-	}
-#endif
-
 	if (client_is_rejected_bot(session)) {
 		log_error(session, "bot rejected");
 		return 403;
@@ -1323,9 +1329,13 @@ void handle_request_result(t_session *session, int result) {
 /* Handle the connection of a client.
  */
 void connection_handler(t_session *session) {
-	int result, connections, timeout;
-
+	int result;
+#ifdef HAVE_SSL
+	int timeout;
+#endif
 #ifdef HAVE_MONITOR
+	int connections;
+
 	connections = ++open_connections;
 	if (session->config->monitor_enabled) {
 		if (connections > session->config->monitor_stats.simultaneous_connections) {
@@ -1643,7 +1653,7 @@ int accept_connection(t_binding *binding, t_config *config) {
 #endif
 	pthread_attr_t      child_attr;
 	pthread_t           child_thread;
-	int                 total_conns, one;
+	int                 total_conns, one, conns_per_ip;
 	struct timeval      timer;
 #ifdef DEBUG
 	static int          thread_id = 0;
@@ -1703,7 +1713,14 @@ int accept_connection(t_binding *binding, t_config *config) {
 
 	kick_client = true;
 
-	if ((total_conns = connection_allowed(&(session->ip_address), config->connections_per_ip, config->total_connections)) >= 0) {
+	session->request_limit = (ip_allowed(&(session->ip_address), session->config->request_limit_mask) != deny);
+	if (session->request_limit == false) {
+		conns_per_ip = config->total_connections;
+	} else {
+		conns_per_ip = config->connections_per_ip;
+	}
+
+	if ((total_conns = connection_allowed(&(session->ip_address), conns_per_ip, config->total_connections)) >= 0) {
 		if (total_conns < (config->total_connections >> 2)) {
 			one = 1;
 			if (setsockopt(session->client_socket, IPPROTO_TCP, TCP_NODELAY, (void*)&one, sizeof(int)) == -1) {
@@ -2259,6 +2276,7 @@ int main(int argc, char *argv[]) {
 			settings.config_check = true;
 		} else if (strcmp(argv[i], "-v") == 0) {
 			printf("%s\n", version_string);
+			printf("Copyright (C) by Hugo Leisink <hugo@leisink.net>\n");
 			return EXIT_SUCCESS;
 		} else {
 			fprintf(stderr, "Unknown option. Use '-h' for help.\n");
