@@ -17,7 +17,7 @@
 #include "libip.h"
 
 typedef enum { deny, allow, pwd, unspecified } t_access;
-typedef enum { tc_data, tc_charlist, tc_accesslist, tc_keyvalue } t_tempdata_type;
+typedef enum { tc_data, tc_charlist, tc_accesslist, tc_keyvalue, tc_errorhandler } t_tempdata_type;
 
 typedef struct type_headerfield {
 	char *data;
@@ -74,6 +74,14 @@ typedef struct type_iplist {
 	struct type_iplist *next;
 } t_iplist;
 
+typedef struct type_error_handler {
+	int  code;
+	char *handler;
+	char *parameters;
+
+	struct type_error_handler *next;
+} t_error_handler;
+
 void sfree(void *ptr);
 
 t_headerfield *parse_headerfields(char *line);
@@ -96,6 +104,9 @@ bool in_iplist(t_iplist *list, t_ip_addr *ip);
 int  parse_keyvaluelist(char *line, t_keyvalue **kvlist, char *delimiter);
 t_keyvalue *remove_keyvaluelist(t_keyvalue *list);
 
+int  parse_error_handler(char *line, t_error_handler **handlers);
+void remove_error_handler(t_error_handler *handler);
+
 int  register_tempdata(t_tempdata **tempdata, void *data, t_tempdata_type type);
 void remove_tempdata(t_tempdata *tempdata);
 
