@@ -193,6 +193,7 @@ bool valid_uri(char *uri) {
 	}
 
 #ifdef CYGWIN
+	// Deny trailing dots and spaces
 	last_pos = strlen(uri) - 1;
 	if (*(uri + last_pos) == '.') {
 		return false;
@@ -200,6 +201,14 @@ bool valid_uri(char *uri) {
 		return false;
 	}
 
+	// Deny 8.3 file format
+	if (last_pos >= 6) {
+		if ((*(uri + last_pos - 5) == '~') && (*(uri + last_pos - 4) >= '0') && 
+			(*(uri + last_pos - 4) <= '9') && (*(uri + last_pos - 3) == '.')) {
+			return false;
+		}
+	}
+
 	if (strstr(uri, "\\.") != NULL) {
 		return false;
 	}
