@@ -64,6 +64,7 @@ static t_host *new_host(void) {
 	host->user_websites      = false;
 	host->execute_cgi        = false;
 	host->time_for_cgi       = 5;
+	host->no_extension_as    = NULL;
 #ifdef HAVE_XSLT
 	host->show_index         = NULL;
 #endif
@@ -252,7 +253,6 @@ t_config *default_config(void) {
 	config->allowed_ciphers    = NULL;
 #endif
 	init_charlist(&(config->cgi_extension));
-	config->no_extension_as    = NULL;
 	config->total_connections  = 100;
 	config->connections_per_ip = 10;
 	config->socket_send_timeout = 3;
@@ -263,7 +263,7 @@ t_config *default_config(void) {
 	config->directory          = NULL;
 	config->throttle           = NULL;
 	config->cgi_handler        = NULL;
-	config->cgi_wrapper        = NULL;
+	config->cgi_wrapper        = SBIN_DIR"/cgi-wrapper";
 	config->wrap_user_cgi      = false;
 	config->log_format         = hiawatha;
 	config->user_directory     = "public_html";
@@ -316,7 +316,7 @@ t_config *default_config(void) {
 #ifdef HAVE_MONITOR
 	config->monitor_enabled    = false;
 	config->monitor_directory  = WORK_DIR"/monitor";
-	config->monitor_stats_interval = 3600;
+	config->monitor_stats_interval = 60 * MINUTE;
 #endif
 
 	return config;
@@ -583,11 +583,6 @@ int check_configuration(t_config *config) {
 			return -1;
 		}
 
-		if ((host->wrap_cgi != NULL) && (config->cgi_wrapper == NULL)) {	
-			fprintf(stderr, "WrapCGI set for host '%s' while CGIwrapper is unset.\n", *(host->hostname.item));
-			return -1;
-		}
-
 		host = host->next;
 	}
 
@@ -898,10 +893,6 @@ static bool system_setting(char *key, char *value, t_config *config) {
 			}
 		}
 #endif
-	} else if (strcmp(key, "noextensionas") == 0) {
-		if ((config->no_extension_as = strdup(value)) != NULL) {
-			return true;
-		}
 	} else if (strcmp(key, "pidfile") == 0) {
 		if (*value == '/') {
 			if ((config->pidfile = strdup(value)) != NULL) {
@@ -1231,6 +1222,10 @@ static bool host_setting(char *key, char *value, t_host *host) {
 			return true;
 		}
 #endif
+	} else if (strcmp(key, "noextensionas") == 0) {
+		if ((host->no_extension_as = strdup(value)) != NULL) {
+			return true;
+		}
 	} else if (strcmp(key, "preventcsrf") == 0) {
 		if (parse_yesno(value, &(host->prevent_csrf)) == 0) {
 			return true;
@@ -1263,7 +1258,7 @@ static bool host_setting(char *key, char *value, t_host *host) {
 			return true;
 		}
 	} else if (strcmp(key, "timeforcgi") == 0) {
-		if ((host->time_for_cgi = str2int(value)) >= 1) {
+		if ((host->time_for_cgi = str2int(value)) > TIMER_OFF) {
 			return true;
 		}
 	} else if (strcmp(key, "triggeroncgistatus") == 0) {
@@ -1411,7 +1406,7 @@ static bool directory_setting(char *key, char *value, t_directory *directory) {
 			}
 		}
 	} else if (strcmp(key, "timeforcgi") == 0) {
-		if ((directory->time_for_cgi = str2int(value)) >= 1) {
+		if ((directory->time_for_cgi = str2int(value)) > TIMER_OFF) {
 			return true;
 		}
 	} else if (strcmp(key, "uploadspeed") == 0) {
@@ -1951,7 +1946,6 @@ int read_user_configfile(char *configfile, t_host *host, t_tempdata **tempdata)
 }
 
 t_host *get_hostrecord(t_host *host, char *hostname, t_binding *binding) {
-	char *dots;
 	size_t len, len_hostname;
 	int i;
 
@@ -1959,10 +1953,6 @@ t_host *get_hostrecord(t_host *host, char *hostname, t_binding *binding) {
 		return NULL;
 	}
 
-	if ((dots = strchr(hostname, ':')) != NULL) {
-		*dots = '\0';
-	}
-
 	if ((len_hostname = strlen(hostname)) == 0) {
 		return NULL;
 	}
