@@ -53,6 +53,7 @@ typedef struct type_session {
 	bool            uri_is_dir;
 	bool            encode_gzip;
 	bool            alias_used;
+	bool            request_limit;
 	t_headerfield   *headerfields;
 	t_ip_addr       ip_address;
 	char            *mimetype;
@@ -121,7 +122,8 @@ bool duplicate_host(t_session *session);
 bool is_volatile_object(t_session *session);
 int  copy_directory_settings(t_session *session);
 bool client_is_rejected_bot(t_session *session);
-int prevent_xss(t_session *session);
+int  remove_port_from_hostname(char *hostname, t_binding *binding);
+int  prevent_xss(t_session *session);
 int  prevent_sqli(t_session *session, char *str, int length, char **newstr);
 int  prevent_csrf(t_session *session);
 void close_socket(t_session *session);
