@@ -153,7 +153,7 @@ void error(t_config *config, char *message) {
 /* Execute file
  */
 int execute_command(char *command, t_exec_type type) {
-	int output_pipe[2], error_pipe[2], result;
+	int output_pipe[2], error_pipe[2], result, skip;
 	int bytes_read, bytes_in_buffer = 0, highest_fd, open_pipes = 2;
 	char buffer[CGI_BUFFER_SIZE], *pos;
 	bool header_read;
@@ -257,10 +257,18 @@ int execute_command(char *command, t_exec_type type) {
 									default:
 										if (header_read == false) {
 											bytes_in_buffer += bytes_read;
-											if ((pos = strstr(buffer, "\r\n\r\n")) != NULL) {
+
+											if ((pos = strstr(buffer, "\r\n\r\n")) == NULL) {
+												pos = strstr(buffer, "\n\n");
+												skip = 2;
+											} else {
+												skip = 4;
+											}
+
+											if (pos != NULL) {
 												/* Skip CGI header
 												 */
-												pos += 4;
+												pos += skip;
 												if (write_buffer(STDOUT_FILENO, pos, bytes_in_buffer - (pos - buffer)) == -1) {
 													return -1;
 												}
