@@ -30,6 +30,7 @@
 #endif
 
 #define VALUE_SIZE 16
+#define LINE_SIZE 1024
 #define XSLT_INDEX "/index.xslt\0"
 #define XSLT_INDEX_LEN 12
 #define MAX_PARAMETERS 200 /* must be even */
@@ -359,13 +360,12 @@ static int apply_xslt_sheet(t_session *session, xmlDocPtr data_xml) {
 
 	/* Read XSLT sheet
 	 */
-	style_xml = xmlReadFile(session->xslt_file, NULL, 0);
-	if (style_xml == NULL) {
+	if ((style_xml = xmlReadFile(session->xslt_file, NULL, 0)) == NULL) {
 		log_file_error(session, session->xslt_file, "XSLT file contains invalid XML");
 		return 500;
 	}
-	xslt = xsltParseStylesheetDoc(style_xml);
-	if (xslt == NULL) {
+
+	if ((xslt = xsltParseStylesheetDoc(style_xml)) == NULL) {
 		log_file_error(session, session->xslt_file, "invalid XSLT");
 		xmlFreeDoc(style_xml);
 		return 500;
@@ -390,15 +390,18 @@ static int apply_xslt_sheet(t_session *session, xmlDocPtr data_xml) {
 	 */
 	if (result_xml == NULL) {
 		log_file_error(session, session->file_on_disk, "transformation error");
+		xmlFreeDoc(result_xml);
 		xsltFreeStylesheet(xslt);
 		return 500;
 	}
 	if ((output = xmlAllocOutputBuffer(NULL)) == NULL) {
+		xmlFreeDoc(result_xml);
 		xsltFreeStylesheet(xslt);
 		return 500;
 	}
     if (xsltSaveResultTo(output, result_xml, xslt) == -1) {
 		log_file_error(session, session->file_on_disk, "transformation error");
+		xmlOutputBufferClose(output);
 		xmlFreeDoc(result_xml);
 		xsltFreeStylesheet(xslt);
 		return 500;
@@ -469,7 +472,7 @@ int add_tag(char **buffer, int *size, int extra_size, int *len, char *tag, char
  */
 int show_index(t_session *session) {
 	xmlDocPtr data_xml;
-	char *text_xml, fsize_str[30], timestr[33], value[VALUE_SIZE + 1], *extension, *link, *slash;
+	char *text_xml, fsize_str[30], timestr[33], value[VALUE_SIZE + 1], *extension, *link, *slash, *ruri;
 	int text_size, text_max, fsize_len, result, handle;
 	off_t total_fsize = 0;
 	bool root_dir, show_xml;
@@ -477,6 +480,11 @@ int show_index(t_session *session) {
 	t_filelist *filelist = NULL, *file;
 	t_keyvalue *alias;
 
+/*
+	FILE *fp;
+	char line[LINE_SIZE + 1];
+*/
+
 #ifdef HAVE_COMMAND
 	increment_counter(COUNTER_INDEX);
 #endif
@@ -490,8 +498,8 @@ int show_index(t_session *session) {
 
 	switch (is_directory(session->file_on_disk)) {
 		case error:
-		case no:
 			return 500;
+		case no:
 		case not_found:
 			return 404;
 		case no_access:
@@ -568,6 +576,7 @@ int show_index(t_session *session) {
 
 	text_max = XML_CHUNK_LEN;
 	if ((text_xml = (char*)malloc(text_max)) == NULL) {
+		remove_filelist(filelist);
 		return -1;
 	}
 	text_size = 0;
@@ -576,15 +585,33 @@ int show_index(t_session *session) {
 	 */
 	if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "<index>") == -1) {
 		free(text_xml);
+		remove_filelist(filelist);
 		return -1;
-	} else if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "hostname", *(session->host->hostname.item)) == -1) {
+	}
+
+	if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "hostname", *(session->host->hostname.item)) == -1) {
 		free(text_xml);
+		remove_filelist(filelist);
 		return -1;
-	} else if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "request_uri", session->request_uri) == -1) {
+	}
+
+	if ((ruri = strdup(session->request_uri)) == NULL) {
 		free(text_xml);
+		remove_filelist(filelist);
 		return -1;
-	} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "<files>") == -1) {
+	}
+	url_decode(ruri);
+	if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "request_uri", ruri) == -1) {
 		free(text_xml);
+		free(ruri);
+		remove_filelist(filelist);
+		return -1;
+	}
+	free(ruri);
+
+	if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "<files>") == -1) {
+		free(text_xml);
+		remove_filelist(filelist);
 		return -1;
 	}
 
@@ -600,9 +627,11 @@ int show_index(t_session *session) {
 
 		if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "<file type=\"") == -1) {
 			free(text_xml);
+			remove_filelist(filelist);
 			return -1;
 		} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, (file->is_dir ? "dir" : "file")) == -1) {
 			free(text_xml);
+			remove_filelist(filelist);
 			return -1;
 		}
 
@@ -614,9 +643,11 @@ int show_index(t_session *session) {
 
 		if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "\" timestamp=\"") == -1) {
 			free(text_xml);
+			remove_filelist(filelist);
 			return -1;
 		} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, timestr) == -1) {
 			free(text_xml);
+			remove_filelist(filelist);
 			return -1;
 		}
 
@@ -626,9 +657,11 @@ int show_index(t_session *session) {
 			fsize_len = filesize2str(fsize_str, 30, file->size);
 			if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "\" size=\"") == -1) {
 				free(text_xml);
+				remove_filelist(filelist);
 				return -1;
 			} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, fsize_str) == -1) {
 				free(text_xml);
+				remove_filelist(filelist);
 				return -1;
 			}
 
@@ -637,9 +670,11 @@ int show_index(t_session *session) {
 			if ((extension = strrchr(file->name, '.')) != NULL) {
 				if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "\" extension=\"") == -1) {
 					free(text_xml);
+					remove_filelist(filelist);
 					return -1;
 				} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, extension + 1) == -1) {
 					free(text_xml);
+					remove_filelist(filelist);
 					return -1;
 				}
 			}
@@ -650,14 +685,17 @@ int show_index(t_session *session) {
 		link = NULL;
 		if (url_encode(file->name, &link) == -1) {
 			free(text_xml);
+			remove_filelist(filelist);
 			return -1;
 		} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "\" url_encoded=\"") == -1) {
 			free(text_xml);
 			sfree(link);
+			remove_filelist(filelist);
 			return -1;
 		} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, link == NULL ? file->name : link) == -1) {
 			free(text_xml);
 			sfree(link);
+			remove_filelist(filelist);
 			return -1;
 		} else {
 			sfree(link);
@@ -665,14 +703,17 @@ int show_index(t_session *session) {
 
 		if (xml_special_chars(file->name, &link) == -1) {
 			free(text_xml);
+			remove_filelist(filelist);
 			return -1;
 		} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "\">") == -1) {
 			free(text_xml);
 			sfree(link);
+			remove_filelist(filelist);
 			return -1;
 		} else if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, link == NULL ? file->name : link) == -1) {
 			free(text_xml);
 			sfree(link);
+			remove_filelist(filelist);
 			return -1;
 		} else {
 			sfree(link);
@@ -681,12 +722,14 @@ int show_index(t_session *session) {
 		if (file->is_dir) {
 			if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "/") == -1) {
 				free(text_xml);
+				remove_filelist(filelist);
 				return -1;
 			}
 		}
 
 		if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "</file>") == -1) {
 			free(text_xml);
+			remove_filelist(filelist);
 			return -1;
 		}
 
@@ -697,11 +740,38 @@ int show_index(t_session *session) {
 		file = file->next;
 	}
 
+	remove_filelist(filelist);
+
 	if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "</files>") == -1) {
 		free(text_xml);
 		return -1;
 	}
 
+/*
+	if ((fp = fopen_neighbour(".hiawatha_index", "r", session->file_on_disk)) != NULL) {
+		if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "<data>") == -1) {
+			free(text_xml);
+			return -1;
+		}
+
+		while (fgets(line, LINE_SIZE, fp) != NULL) {
+			line[LINE_SIZE] = '\0';
+			
+			if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, line) == -1) {
+				free(text_xml);
+				return -1;
+			}
+		}
+
+		fclose(fp);
+
+		if (add_str(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "</data>") == -1) {
+			free(text_xml);
+			return -1;
+		}
+	}
+*/
+
 	if (session->remote_user != NULL) {
 		if (add_tag(&text_xml, &text_max, XML_CHUNK_LEN, &text_size, "remote_user", session->remote_user) == -1) {
 			free(text_xml);
